package ru.myitschool.work.api.domain.entity.employee;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import java.util.List;

public class EmployeeEntity {
    private final long id;
    @NonNull private final String name;
    @NonNull private final String surname;
    @Nullable private final String patronymic;
    @NonNull private final String telephone;
    @NonNull private final String email;

    private final long officeId;
    @NonNull private final String officeName;
    @NonNull private final String officeImageUrl;

    @NonNull private final String position; // Название должности
    @NonNull private final String role; // строка либо ROLE_USER, либо ROLE_ADMIN

    @NonNull private final String profileImageUrl;

    // Текущее состояние входа: false - visit (посещение) ещё не началось, true - visit идёт
    private final boolean visitStatus;

    // Если visitStatus true, то возвращает дату и время начала посещения в формате LocalDateTime.toString(),
    // превратить обратно можно с помощью LocalDateTime.parse().
    // Если visitStatus false, то возвращает null.
    @NonNull private final String startVisitDateTime;
    @NonNull private final List<Long> visitsIdLast30Days; // Список Id посещений за последние 30 дней.

    // Возвращает количество отработанных часов за последний месяц.
    private final long totalTimeVisitsLast30Days;

    // (Возможно это стоит убрать) Название офиса, в котором сейчас находится работник.
    // Если visitStatus false, возвращает null.
    @NonNull private final String currentOfficeName;

    // Возвращает время регистрации в формате LocalDateTime.toString(),
    // превратить обратно можно с помощью LocalDateTime.parse().
    @NonNull private final String createAt;

    public EmployeeEntity(long id, @NonNull String name, @NonNull String surname, @Nullable String patronymic, @NonNull String telephone, @NonNull String email, long officeId, @NonNull String officeName, @NonNull String officeImageUrl, @NonNull String position, @NonNull String role, @NonNull String profileImageUrl, boolean visitStatus, @NonNull String startVisitDateTime, @NonNull List<Long> visitsIdLast30Days, long totalTimeVisitsLast30Days, @NonNull String currentOfficeName, @NonNull String createAt) {
        this.id = id;
        this.name = name;
        this.surname = surname;
        this.patronymic = patronymic;
        this.telephone = telephone;
        this.email = email;
        this.officeId = officeId;
        this.officeName = officeName;
        this.officeImageUrl = officeImageUrl;
        this.position = position;
        this.role = role;
        this.profileImageUrl = profileImageUrl;
        this.visitStatus = visitStatus;
        this.startVisitDateTime = startVisitDateTime;
        this.visitsIdLast30Days = visitsIdLast30Days;
        this.totalTimeVisitsLast30Days = totalTimeVisitsLast30Days;
        this.currentOfficeName = currentOfficeName;
        this.createAt = createAt;
    }

    @NonNull
    public String getCreateAt() {
        return createAt;
    }

    @NonNull
    public String getCurrentOfficeName() {
        return currentOfficeName;
    }

    public long getTotalTimeVisitsLast30Days() {
        return totalTimeVisitsLast30Days;
    }

    @NonNull
    public List<Long> getVisitsIdLast30Days() {
        return visitsIdLast30Days;
    }

    @NonNull
    public String getStartVisitDateTime() {
        return startVisitDateTime;
    }

    public boolean isVisitStatus() {
        return visitStatus;
    }

    @NonNull
    public String getProfileImageUrl() {
        return profileImageUrl;
    }

    @NonNull
    public String getRole() {
        return role;
    }

    @NonNull
    public String getPosition() {
        return position;
    }

    @NonNull
    public String getOfficeImageUrl() {
        return officeImageUrl;
    }

    @NonNull
    public String getOfficeName() {
        return officeName;
    }

    public long getOfficeId() {
        return officeId;
    }

    @NonNull
    public String getEmail() {
        return email;
    }

    @NonNull
    public String getTelephone() {
        return telephone;
    }

    @Nullable
    public String getPatronymic() {
        return patronymic;
    }

    @NonNull
    public String getSurname() {
        return surname;
    }

    @NonNull
    public String getName() {
        return name;
    }

    public long getId() {
        return id;
    }
}
