package ru.myitschool.work.ui.screens;

import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.text.Editable;
import android.view.View;
import android.widget.Button;

import androidx.activity.EdgeToEdge;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.graphics.Insets;
import androidx.core.view.ViewCompat;
import androidx.core.view.WindowInsetsCompat;
import androidx.lifecycle.ViewModelProvider;

import com.example.myapplication.core.SettingConstants;
import com.google.android.material.snackbar.Snackbar;
import com.google.android.material.textfield.TextInputEditText;
import com.google.android.material.textfield.TextInputLayout;

import ru.myitschool.work.R;
import ru.myitschool.work.ui.viewModel.LoginViewModel;
import ru.myitschool.work.utils.TextChangedListener;

public class LoginActivity extends AppCompatActivity {
    private Button loginButton;
    private TextInputEditText email;
    private TextInputLayout emailLayout;
    private TextInputEditText password;
    private TextInputLayout passwordLayout;
    private LoginViewModel viewModel;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        EdgeToEdge.enable(this);
        setContentView(R.layout.activity_login);
        ViewCompat.setOnApplyWindowInsetsListener(findViewById(R.id.main), (v, insets) -> {
            Insets systemBars = insets.getInsets(WindowInsetsCompat.Type.systemBars());
            v.setPadding(systemBars.left, systemBars.top, systemBars.right, systemBars.bottom);
            return insets;
        });

        loginButton = findViewById(R.id.loginButton);
        email = findViewById(R.id.email);
        emailLayout = findViewById(R.id.email_layout);
        password = findViewById(R.id.password);
        passwordLayout = findViewById(R.id.password_layout);

        viewModel = new ViewModelProvider(this).get(LoginViewModel.class);

        email.addTextChangedListener(new TextChangedListener<>(email) {
            @Override
            public void onTextChanged(TextInputEditText target, Editable s) {
                listenerEmailEditText(s);
            }
        });
        password.addTextChangedListener(new TextChangedListener<>(password) {
            @Override
            public void onTextChanged(TextInputEditText target, Editable s) {
                listenerPasswordEditText(s);
            }
        });

        loginButton.setOnClickListener(this::onClickListenerLoginButton);
        subscribe();
    }

    private void subscribe() {
        viewModel.errorLiveData.observe(this, error -> {
            loginButton.setEnabled(true);
            Snackbar.make(findViewById(android.R.id.content), error, Snackbar.LENGTH_LONG).show();
        });
        viewModel.openLiveData.observe(this, employee -> {
            loginButton.setEnabled(true);

            SharedPreferences settings = getSharedPreferences(
                    SettingConstants.PREFS_FILE, Context.MODE_PRIVATE
            );
            settings.edit().putLong(SettingConstants.PREF_ID, employee.getId()).apply();
            settings.edit().putString(SettingConstants.PREF_ROLE, employee.getRole()).apply();

            startActivity(new Intent(this, MainActivity.class));
            finish();
        });
    }

    private void listenerEmailEditText(Editable s) {
        if (s.toString().isEmpty()) {
            emailLayout.setError("Обязательное поле");
        } else if (!isEmailValid(s.toString())) {
            emailLayout.setError("Неверный формат");
        } else {
            emailLayout.setErrorEnabled(false);
        }
    }

    private void listenerPasswordEditText(Editable s) {
        if (s.toString().isEmpty()) {
            passwordLayout.setError("Обязательное поле");
        } else {
            passwordLayout.setErrorEnabled(false);
        }
    }

    private void onClickListenerLoginButton(View view) {
        loginButton.setEnabled(false);

        viewModel.changeEmail(String.valueOf(email.getText()));
        viewModel.changePassword(String.valueOf(password.getText()));
        viewModel.confirm();
    }

    private boolean isEmailValid(String email) {
        return android.util.Patterns.EMAIL_ADDRESS.matcher(email).matches();
    }
}